@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10258 2017-09-04 08:44:52Z David $
+# $Id: Mailer.py 10284 2017-09-10 17:17:32Z David $
 #
 # Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10258 $
+# $Revision: 10284 $
 
 import os
 import random
@@ -223,7 +223,7 @@ class CloudMailer(Mailer):
                 raise RuntimeError('Failed...')
         except Exception as e:
             s = '%s failed.' % _s
-            self.logger.info('[%d]_TEST_FAILED: %s.' % (newsletterId, s))
+            self.logger.error('[%d]_TEST_FAILED: %s.' % (newsletterId, s))
             raise e
         finally:
             s = '%s end.' % _s
@@ -362,13 +362,13 @@ class CloudMailer(Mailer):
             contact.save()
             _eMsg = str(e)
             resultMessage = 'Send mail failed: %s.' % _eMsg
-            self.logger.info(
+            self.logger.error(
                 '[%d]_FAILED: Send mail to contact<%d> failed, %s.' %
                 (newsletterId, contactId, _eMsg))
         except Exception as e:
             _eMsg = getComment(e)
             resultMessage = 'Send mail failed: %s.' % _eMsg
-            self.logger.info(
+            self.logger.error(
                 '[%d]_FAILED: Send mail to contact<%d> failed, %s.' %
                 (newsletterId, contactId, _eMsg))
 
@@ -387,7 +387,7 @@ class CloudMailer(Mailer):
                     else:
                         status = ContactMailingStatus.ERROR
                 except Exception as e:
-                    self.logger.info(
+                    self.logger.error(
                         '[%d]_GET_ERROR_INFO_FAILED: contact<%d>.' %
                         (newsletterId, contactId))
                     status = ContactMailingStatus.ERROR
@@ -469,13 +469,13 @@ class CloudMailer(Mailer):
 
             s = ('[%d][run]_FAILED: %s,' % (newsletterId, _s))
             if isinstance(e, NoResultsPending):
-                self.logger.info('%s reason: NoResultsPending, %s.' % 
+                self.logger.error('%s reason: NoResultsPending, %s.' % 
                                  (s, str(e)))
             elif isinstance(e, NoWorkersAvailable):
-                self.logger.info('%s reason: NoWorkersAvailable, %s.' % 
+                self.logger.error('%s reason: NoWorkersAvailable, %s.' % 
                                  (s, str(e)))
             else:
-                self.logger.info('%s reason: %s.' % (s, getComment(e)))
+                self.logger.error('%s reason: %s.' % (s, getComment(e)))
         finally:
                        
             if self.smtp:
