@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backend.py 9594 2016-03-18 12:59:58Z Judy $
+# $Id: Backend.py 10352 2017-10-08 04:46:26Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-18 20:59:58 +0800 (五, 18  3 2016) $
-# $Revision: 9594 $
+# $Author: David $
+# $Date: 2017-10-08 12:46:26 +0800 (Sun, 08 Oct 2017) $
+# $Revision: 10352 $
 
 from urllib import urlopen, urlencode, quote
 from django.core.mail.backends.base import BaseEmailBackend
@@ -34,7 +34,6 @@ class EmailBackend(BaseEmailBackend):
         # admin$templates_shop$templates_shop_mails
         if '$' in username:
             appInfo = username.split('$')
-            print appInfo
             self.username = appInfo[0]
             self.appName = appInfo[1]
             if len(appInfo) > 2:
